# Same as before, with a kivy-based UI

'''
Bluetooth/Pyjnius example
=========================
This was used to send some bytes to an arduino via bluetooth.
The app must have BLUETOOTH and BLUETOOTH_ADMIN permissions (well, i didn't
tested without BLUETOOTH_ADMIN, maybe it works.)
Connect your device to your phone, via the bluetooth menu. After the
pairing is done, you'll be able to use it in the app.
'''

from jnius import autoclass
from kivy.app import App
from kivy.uix.boxlayout import BoxLayout
from kivy.uix.button import Button

BluetoothAdapter = autoclass('android.bluetooth.BluetoothAdapter')
BluetoothDevice = autoclass('android.bluetooth.BluetoothDevice')
BluetoothSocket = autoclass('android.bluetooth.BluetoothSocket')
UUID = autoclass('java.util.UUID')


def get_socket_stream(name):
    paired_devices = BluetoothAdapter.getDefaultAdapter().getBondedDevices().toArray()
    socket = None
    for device in paired_devices:
        if device.getName() == name:
            socket = device.createRfcommSocketToServiceRecord(
                UUID.fromString("00001101-0000-1000-8000-00805F9B34FB"))
            recv_stream = socket.getInputStream()
            send_stream = socket.getOutputStream()
            break
    socket.connect()
    return recv_stream, send_stream


class Bluetooth(App):
    def build(self):
        self.recv_stream, self.send_stream=None,None
        #On cree une disposition pour l'affichage:
        Layout=BoxLayout(orientation='vertical',spacing=20,padding=(200,20))
        self.GD=BoxLayout(orientation='horizontal',spacing=20,padding=(0,0))
        self.BoutonConnect=Button(text='Connect')
        self.BoutonConnect.bind(on_press=self.connect)
        #On ajoute le bouton dans l'affichage:
        Layout.add_widget(self.BoutonConnect)
        #On cree des boutons pour les motifs:
        self.Bouton1=Button(text='Up')
        self.Bouton1.id='1'
        self.Bouton1.bind(on_press=self.send)
        self.Bouton1.bind(on_release=self.stop)
        #On ajoute le bouton dans l'affichage:
        Layout.add_widget(self.Bouton1)
        
        self.Bouton2=Button(text='Left')
        self.Bouton2.id='2'
        self.Bouton2.bind(on_press=self.send)
        self.Bouton2.bind(on_release=self.stop)
        #On ajoute le bouton dans l'affichage:
        self.GD.add_widget(self.Bouton2)
        self.Bouton3=Button(text='Right')
        self.Bouton3.id='3'
        self.Bouton3.bind(on_press=self.send)
        self.Bouton3.bind(on_release=self.stop)
        #On ajoute le bouton dans l'affichage:
        self.GD.add_widget(self.Bouton3)
        Layout.add_widget(self.GD)
        self.Bouton4=Button(text='Back')
        self.Bouton4.id='5'
        self.Bouton4.bind(on_press=self.send)
        self.Bouton4.bind(on_release=self.stop)
        #On ajoute le bouton dans l'affichage:
        Layout.add_widget(self.Bouton4)
        return Layout
        
    def connect(self,instance):
        self.recv_stream, self.send_stream = get_socket_stream('HC-06')
        if self.send_stream!=None:
            instance.background_color=[0,1,0,1]
            instance.text="connected"
        

    def send(self, instance):
        self.send_stream.write(int(instance.id))
        self.send_stream.flush()
    
    def stop(self, instance):
        self.send_stream.write(4)
        self.send_stream.flush()
            
if __name__ == '__main__':
    Bluetooth().run()